bayespy.inference.vmp.nodes.stochastic.Distribution.compute_message_to_parent
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Distribution.compute_message_to_parent